"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const https_1 = __importDefault(require("https"));
const global_1 = require("./types/global");
class MonerisCheckout {
    constructor(storeID, apiToken, checkoutID, environment = global_1.EnvironmentType.TEST) {
        this.storeID = storeID;
        this.apiToken = apiToken;
        this.checkoutID = checkoutID;
        this.environment = environment;
        this.requestOption = {
            hostname: global_1.Hosts[this.environment],
            port: 443,
            path: "/" + global_1.EndPoints[this.environment],
            method: "POST",
            headers: {
                "Content-Type": "application/json"
            }
        };
    }
    preload(totalPrice, optionalData = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = Object.assign({}, optionalData);
            payload.store_id = this.storeID;
            payload.api_token = this.apiToken;
            payload.checkout_id = this.checkoutID;
            payload.environment = this.environment;
            payload.txn_total = totalPrice.toFixed(2);
            payload.action = global_1.RequestType.PRELOAD;
            return yield this.sendRequest(this.requestOption, payload);
        });
    }
    receipt(ticket) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = {
                store_id: this.storeID,
                api_token: this.apiToken,
                checkout_id: this.checkoutID,
                environment: this.environment,
                action: global_1.RequestType.RECEIPT,
                ticket
            };
            return yield this.sendRequest(this.requestOption, payload);
        });
    }
    sendRequest(option, data) {
        return new Promise((resolve, reject) => {
            let response = "";
            const req = https_1.default.request(option, (res) => {
                res.on("data", (d) => {
                    response += d;
                });
                res.on("end", () => {
                    resolve(JSON.parse(response));
                });
            });
            req.on('error', (e) => {
                reject(e);
            });
            req.write(JSON.stringify(data));
            req.end();
        });
    }
}
exports.default = MonerisCheckout;
;
//# sourceMappingURL=moneris-checkout.js.map